@@ -122,7 +122,57 @@ def _to_3x_uint8(arr):
     return arr
 
 
-vis_depth = _to_3x_uint8
+def vis_depth(depth, slicen=0, fix_range=None, colormap=None):
+    if depth.ndim == 3 and depth.shape[-1] in [3, 4]:
+        return depth
+    if depth.dtype == np.uint16:
+        depth = depth / 1000.0
+    raw_depth = depth
+    if fix_range:
+        if isinstance(fix_range, (float, int)):
+            fix_range = (0, fix_range)
+        depth = depth.clip(*fix_range)
+        normaed = (depth - fix_range[0]) / (fix_range[1] - fix_range[0])
+    else:
+        normaed = boxx.norma(depth)
+    if slicen:
+        normaed = (normaed * slicen) % 1
+        if colormap is None:
+            colormap = cv2.COLORMAP_HSV
+    depth_uint8 = np.uint8(normaed * 255.9)
+    vis = cv2.applyColorMap(depth_uint8, colormap or cv2.COLORMAP_JET)[..., ::-1]
+    vis[raw_depth == 0] = 0
+    return vis
+
+
+def vis_point_uvs(uvs, img_or_shape=None, size=None, color=None):
+    if isinstance(img_or_shape, np.ndarray) and img_or_shape.ndim >= 2:
+        vis = img_or_shape.copy()
+    else:
+        if img_or_shape is None:
+            img_or_shape = [int(uvs[:, :2].max() * 1.1)] * 2
+        vis = np.ones(img_or_shape, np.uint8) * 128
+    if vis.ndim == 2:
+        vis = np.concatenate([vis[:, :, None]] * 3, -1)
+    if size is None:
+        size = 1.0
+    if size < 5 and isinstance(size, float):
+        size = np.sum(vis.shape[:2]) * 0.001 * size
+        size = max(1, size)
+    size = int(round(size))
+    for idx, uv in enumerate(uvs):
+        if color is None:
+            vis = cv2.circle(
+                vis, tuple(np.int32(uv[:2])), size * 2, (255, 255, 255), -1
+            )
+        vis = cv2.circle(
+            vis,
+            tuple(np.int32(uv[:2])),
+            size,
+            (255, 0, 0) if color is None else color,
+            -1,
+        )
+    return vis
 
 
 def vis_stereo(img1, img2, n_line=21, thickness=0.03):
